/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.model.internal.outcomes;

import org.gradle.api.Nullable;

import java.io.File;

/**
 * A build outcome, that is represented as a file.
 *
 * @since 1.2
 */
public interface GradleFileBuildOutcome extends GradleBuildOutcome {

    /**
     * The file, were it was produced by the build.
     *
     * May be a file or a directory.
     *
     * @return The file.
     */
    File getFile();

    /**
     * A canonical identifier for what the outcome is.
     *
     * The string is free form, but there is expected to be agreement between the
     * server and client about the values. For example, the {@link #getFile()} may have any file extension
     * while the “type identifier” is “zip” to convey that it is a zip file.
     *
     * If the value is {@code null}, A type identifier could not be determined.
     *
     * @return The unique type identifier for the file.
     */
    @Nullable
    String getTypeIdentifier();

}
